@@ -116,7 +116,7 @@ class Connection(object):
     ):
         username = username
         password = password
-        database = database
+        self.database = database
         port = port
         scheme = "e6xdb"
 
@@ -173,6 +173,9 @@ class Connection(object):
     def query_cancel(self, query_id):
         self._client.cancelQuery(queryId=query_id)
 
+    def get_tables(self, database):
+        self._client.getTables(schema=database)
+
     def commit(self):
         """Hive does not support transactions, so this does nothing."""
         pass
@@ -264,6 +267,10 @@ class Cursor(DBAPICursor):
         self.connection.close(self._query_id)
         pass
 
+    def getTables(self):
+        schema = self.connection.database
+        self.connection.get_tables(database=schema)
+
     def clear(self):
         """Clears the tmp data"""
         self.connection.clear(self._query_id)
